This is an automated email from the ASF dual-hosted git repository.

tqchen pushed a commit to branch refactor-docker-bash-sh
in repository https://gitbox.apache.org/repos/asf/tvm.git

commit 5e98b4ac671ddeda40e34273390ab08db1f459d5
Author: tqchen <[email protected]>
AuthorDate: Sat Feb 28 19:59:41 2026 +0000

    [DOCKER] Rename TVM_DEV_MOUNTS to TVM_DEV_DOCKER_MOUNTS
---
 docker/bash.sh | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/docker/bash.sh b/docker/bash.sh
index 308266f4d1..ff4c902fbc 100755
--- a/docker/bash.sh
+++ b/docker/bash.sh
@@ -170,7 +170,7 @@ COMMAND
 
 Environment Variables:
 
-TVM_DEV_MOUNTS
+TVM_DEV_DOCKER_MOUNTS
 
     Space-separated list of additional mount specifications.
     Each entry is either:
@@ -455,10 +455,10 @@ for MOUNT_DIR in ${MOUNT_DIRS[@]+"${MOUNT_DIRS[@]}"}; do
     DOCKER_MOUNT+=( --volume "${MOUNT_DIR}:${MOUNT_DIR}" )
 done
 
 # Parse TVM_DEV_MOUNTS env var: space-separated mount specs
 # Each entry is either /path (same path) or /src:/dst
-if [[ -n "${TVM_DEV_MOUNTS:-}" ]]; then
-    for mount_spec in ${TVM_DEV_MOUNTS}; do
+if [[ -n "${TVM_DEV_DOCKER_MOUNTS:-}" ]]; then
+    for mount_spec in ${TVM_DEV_DOCKER_MOUNTS}; do
         if [[ "$mount_spec" == *:* ]]; then
             # src:dst format
             mount_src="${mount_spec%%:*}"
@@ -455,10 +455,10 @@ for MOUNT_DIR in ${MOUNT_DIRS[@]+"${MOUNT_DIRS[@]}"}; do
 done
 
-# Parse TVM_DEV_MOUNTS env var: space-separated mount specs
+# Parse TVM_DEV_DOCKER_MOUNTS env var: space-separated mount specs
 # Each entry is either /path (same path) or /src:/dst

Reply via email to